@@ -185,7 +185,7 @@ use Data::Dumper;
 use base 'Exporter';
 use v5.14;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 our @EXPORT = qw{
 	one_row
@@ -752,7 +752,7 @@ sub make_object_update {
 						}
 					}
 				);
-				pop \@{\$self};
+				\$#\$self = @{[_row_data]};
 			}
 			\$self;
 		}
